import argparse, os
from xml.etree import ElementTree


def processVcxproj(vcxproj, attribArg, valueArg):
	et = ElementTree.parse(vcxproj)
	root = et.getroot()
	namespaces = {node[0]: node[1] for _, node in ElementTree.iterparse(vcxproj, events=['start-ns'])}
	for key, value in namespaces.items():
	    ElementTree.register_namespace(key, value)

	default_ns = "{" + namespaces[""] + "}"
	activ_tag = root.find(".//" + default_ns + attribArg)

	if activ_tag == None:
		for child in root:
			if ("PropertyGroup" in child.tag and "Globals" in str(child.attrib)):
				activ_tag = ElementTree.SubElement(child, attribArg)

	activ_tag.text = valueArg
	et.write(vcxproj, encoding='utf-8', xml_declaration=True) 


def main(args):
	vcxproj, attribArg, valueArg = [args.vs, args.a, args.v]
	if not os.path.exists(vcxproj):
		print("*** Could not find vcxproj file.")
		return -1

	print("Looking at this file: %s" % vcxproj)
	print("Going to add attribute: '%s' with value: '%s'\n" % (attribArg,valueArg))
	processVcxproj(vcxproj, attribArg, valueArg)


parser = argparse.ArgumentParser(description='Add config attributes to VS export.')
parser.add_argument('vs', metavar='myExport.vcxproj', type=str, help = 'Visual Studio VCXProj file')
parser.add_argument('a', metavar='UseIntelMKL', type=str, help = 'The attribute you want to add to the default app config.')
parser.add_argument('v', metavar='Parallel', type=str, help = 'The value you want to assign ot the attribute.')

args = parser.parse_args()
main(args)
